[OGDF](../README.md) » [Developer's Guide](dev-guide.md) » Porting Guide

# Porting Guide {#porting}

Compatibility-breaking changes are changes that may require OGDF users to
change their code after an OGDF update.

The following files describe compatibility-breaking changes
for this and former OGDF versions:

  * [from Foxglove to the current unreleased version](porting/unreleased.md)
  * [from Elderberry to Foxglove](porting/foxglove.md)
  * [from Dogwood to Elderberry](porting/elderberry.md)
  * [from Catalpa to Dogwood](porting/dogwood.md)
  * [from Baobab to Catalpa](porting/catalpa.md)
  * [from Sakura to Baobab](porting/baobab.md)
